@@ -19,7 +19,6 @@
 * MA 02110-1301, USA.
 */
 
-#include <gtk/gtk.h>
 #include "oxygeninnershadowdata.h"
 #include "../oxygengtkutils.h"
 #include "../config.h"
@@ -28,7 +27,9 @@
 #include "oxygenanimations.h"
 #include "../oxygenstyle.h"
 #include "../oxygenmetrics.h"
-#include <stdlib.h>
+
+#include <gtk/gtk.h>
+#include <cstdlib>
 
 #include <cassert>
 #include <iostream>
@@ -46,11 +47,8 @@ namespace Oxygen
         // store target
         _target = widget;
 
-        if( gdk_display_supports_composite( gtk_widget_get_display( widget ) ) && G_OBJECT_TYPE_NAME(widget) != std::string("GtkPizza") )
-        {
-            _compositeEnabled = true;
-            _exposeId.connect( G_OBJECT(_target), "expose-event", G_CALLBACK( targetExposeEvent ), this, true );
-        }
+        if( gdk_display_supports_composite( gtk_widget_get_display( widget ) ) )
+        { _exposeId.connect( G_OBJECT(_target), "expose-event", G_CALLBACK( targetExposeEvent ), this, true ); }
 
         // check child
         GtkWidget* child( gtk_bin_get_child( GTK_BIN( widget ) ) );
@@ -108,9 +106,6 @@ namespace Oxygen
             // check compositing
             gdk_display_supports_composite( gtk_widget_get_display( widget ) ) &&
 
-            // check widget type (might move to blacklist method)
-            ( G_OBJECT_TYPE_NAME(widget) != std::string("GtkPizza") ) &&
-
             // make sure widget is scrollable
             GTK_WIDGET_GET_CLASS( widget )->set_scroll_adjustments_signal )
         {
