@@ -38,6 +38,7 @@
 #include <fstream>
 #include <iostream>
 #include <sstream>
+#include <unistd.h>
 
 namespace Oxygen
 {
@@ -71,6 +72,7 @@ namespace Oxygen
         _menuHighlightMode( MM_DARK ),
         _windowDragEnabled( true ),
         _windowDragMode( WD_FULL ),
+        _useWMMoveResize( true ),
         _startDragDist( 4 ),
         _startDragTime( 500 ),
         _animationsEnabled( true ),
@@ -89,6 +91,7 @@ namespace Oxygen
         _windecoBlendType( FollowStyleHint ),
         _activeShadowConfiguration( Palette::Active ),
         _inactiveShadowConfiguration( Palette::Inactive ),
+        _backgroundOpacity( 255 ),
         _argbEnabled( true ),
         _initialized( false ),
         _kdeColorsInitialized( false ),
@@ -210,30 +213,7 @@ namespace Oxygen
 
     //_________________________________________________________
     bool QtSettings::runCommand( const std::string& command, char*& result ) const
-    {
-
-        if( FILE* fp = popen( command.c_str(), "r" ) )
-        {
-
-            // read command output. Make sure that the buffer is large enough to read the entire
-            // output, by multiplying its initial size by two as long as the last character is not '\n'
-            // note that the allocated string must be freed by the calling method
-            gulong bufSize=512;
-            size_t currentOffset=0;
-            result= static_cast<char*>(g_malloc(bufSize));
-            while( fgets( result+currentOffset, bufSize-currentOffset, fp ) && result[strlen(result)-1] != '\n' )
-            {
-                currentOffset = bufSize-1;
-                bufSize *= 2;
-                result = static_cast<char*>( g_realloc( result, bufSize ) );
-            }
-
-            pclose(fp);
-            return true;
-
-        } else return false;
-
-    }
+    { return g_spawn_command_line_sync( command.c_str(), &result, 0L, 0L, 0L ) && result; }
 
     //_________________________________________________________
     bool QtSettings::loadKdeGlobals( void )
@@ -349,7 +329,14 @@ namespace Oxygen
         // make sure that corresponding directory does exist
         struct stat st;
         if( stat( _userConfigDir.c_str(), &st ) != 0 )
-        { mkdir( _userConfigDir.c_str(), S_IRWXU|S_IRWXG|S_IRWXO ); }
+        {
+
+            #if _POSIX_C_SOURCE
+            mkdir( _userConfigDir.c_str(), S_IRWXU|S_IRWXG|S_IRWXO );
+            #else
+            mkdir( _userConfigDir.c_str() );
+            #endif
+        }
 
         // note: in some cases, the target might exist and not be a directory
         // nothing we can do about it. We won't overwrite the file to prevent dataloss
@@ -699,6 +686,7 @@ namespace Oxygen
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  text[PRELIGHT]", _palette.color( Palette::Text ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  text[SELECTED]", _palette.color( Palette::SelectedText ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  text[INSENSITIVE]", _palette.color( Palette::Disabled, Palette::Text ) ) );
+        addLinkColors( "[Colors:Window]" );
 
         // buttons
         _rc.addSection( "oxygen-buttons-internal", Gtk::RC::defaultSection() );
@@ -710,6 +698,8 @@ namespace Oxygen
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  fg[ACTIVE]", _palette.color( Palette::ButtonText ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  fg[PRELIGHT]", _palette.color( Palette::ButtonText ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  fg[INSENSITIVE]", _palette.color( Palette::Disabled, Palette::ButtonText ) ) );
+        addLinkColors( "[Colors:Button]" );
+
         _rc.matchClassToSection( "*Button", "oxygen-buttons-internal" );
         _rc.matchClassToSection( "GtkOptionMenu", "oxygen-buttons-internal" );
         _rc.matchWidgetClassToSection( "*<GtkButton>.<GtkLabel>", "oxygen-buttons-internal" );
@@ -781,6 +771,7 @@ namespace Oxygen
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  bg[NORMAL]", _palette.color( Palette::Base ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  bg[INSENSITIVE]", _palette.color( Palette::Disabled, Palette::Base ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  base[INSENSITIVE]", _palette.color( Palette::Disabled, Palette::Base ) ) );
+        addLinkColors( "[Colors:View]" );
         _rc.matchClassToSection( "GtkSpinButton", "oxygen-entry-internal" );
         _rc.matchClassToSection( "GtkEntry", "oxygen-entry-internal" );
         _rc.matchClassToSection( "GtkTextView", "oxygen-entry-internal" );
@@ -793,6 +784,8 @@ namespace Oxygen
         _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  fg[NORMAL]", _palette.color( Palette::TooltipText ) ) );
         _rc.addToCurrentSection( Gtk::RCOption<int>( "  xthickness", 3 ) );
         _rc.addToCurrentSection( Gtk::RCOption<int>( "  ythickness", 3 ) );
+        addLinkColors( "[Colors:Tooltip]" );
+
         _rc.matchWidgetToSection( "gtk-tooltip*", "oxygen-tooltips-internal" );
 
         // special case for google chrome
@@ -804,6 +797,33 @@ namespace Oxygen
 
     }
 
+
+    //_________________________________________________________
+    void QtSettings::addLinkColors( const std::string& section )
+    {
+
+        {
+            // link colors
+            // from http://ubuntuforums.org/showthread.php?p=7009302
+            const ColorUtils::Rgba linkColor( ColorUtils::Rgba::fromKdeOption( _kdeGlobals.getValue( section, "ForegroundLink" ) ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkWidget::link-color", linkColor ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkHTML::alink_color", linkColor ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkHTML::link_color", linkColor ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GnomeHref::link-color", linkColor ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkIMHtml::hyperlink-color", linkColor ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkIMHtml::hyperlink-prelight-color", linkColor ) );
+        }
+
+        {
+            // visited link colors
+            // from http://ubuntuforums.org/showthread.php?p=7009302
+            const ColorUtils::Rgba visitedLinkColor( ColorUtils::Rgba::fromKdeOption( _kdeGlobals.getValue( section, "ForegroundVisited" ) ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkWidget::visited-link-color", visitedLinkColor ) );
+            _rc.addToCurrentSection( Gtk::RCOption<std::string>( "  GtkHTML::vlink_color", visitedLinkColor ) );
+        }
+
+    }
+
     //_________________________________________________________
     void QtSettings::loadKdeFonts( void )
     {
@@ -971,6 +991,9 @@ namespace Oxygen
         if( windowDragMode == "WD_MINIMAL" ) _windowDragMode = WD_MINIMAL;
         else _windowDragMode = WD_FULL;
 
+        // use window manager to handle window drag
+        _useWMMoveResize = _oxygen.getOption( "[Style]", "UseWMMoveResize" ).toVariant<std::string>("true") == "true";
+
         // animations
         _animationsEnabled = ( _oxygen.getOption( "[Style]", "AnimationsEnabled" ).toVariant<std::string>("true") == "true" );
         _genericAnimationsEnabled = ( _oxygen.getOption( "[Style]", "GenericAnimationsEnabled" ).toVariant<std::string>("true") == "true" );
@@ -1042,6 +1065,11 @@ namespace Oxygen
         _activeShadowConfiguration.initialize( _oxygen );
         _inactiveShadowConfiguration.initialize( _oxygen );
 
+        if(_kdeGlobals.getOption( "[General]", "widgetStyle" ).toVariant<std::string>("oxygen") == "oxygen transparent")
+            _backgroundOpacity = _oxygen.getOption( "[Common]", "BackgroundOpacity" ).toVariant<int>(255);
+        else
+            _backgroundOpacity = 255;
+
         #if OXYGEN_DEBUG
         std::cerr << _activeShadowConfiguration << std::endl;
         std::cerr << _inactiveShadowConfiguration << std::endl;
